@@ -10,7 +10,7 @@ use File::Basename;
 
 my ($target) = @ARGV;
 
-my @libs = glob "lib/*.a";
+my @libs = glob "lib*.a";
 my @headers;
 
 find({
@@ -22,14 +22,16 @@ find({
 }, 'upb');
 
 for my $lib (@libs) {
-    my $dest = "$target/$lib";
+    my $dest = "$target/lib/$lib";
 
     mkpath(dirname($dest));
     copy($lib, $dest) or die "Error copying '$lib' to '$dest': $!";
 }
 
 for my $header (@headers) {
-    my $dest = "$target/include/$header";
+    my $dest = $header =~ m{generated_for_cmake[/\\](.*)} ?
+        "$target/include/$1" :
+        "$target/include/$header";
 
     mkpath(dirname($dest));
     copy($header, $dest) or die "Error copying '$header' to '$dest': $!";
